=======
molotov
=======


.. image:: http://coveralls.io/repos/github/loads/molotov/badge.svg?branch=master
   :target: https://coveralls.io/github/loads/molotov?branch=master

.. image:: http://travis-ci.org/loads/molotov.svg?branch=master
   :target: https://travis-ci.org/loads/molotov

.. image:: http://readthedocs.org/projects/molotov/badge/?version=latest
   :target: https://readthedocs.org/projects/molotov


Simple Python 3.5+ tool to write load tests.

Based on `asyncio <https://docs.python.org/3/library/asyncio.html>`_,
`aiohttp.client <http://aiohttp.readthedocs.io/en/stable/client.html>`_ and
`Urwid <http://urwid.org/>`_ for its curses console.

`Full Documentation <https://molotov.readthedocs.io>`_

